haze
====

|GitHub stars| |Code Climate| |Issue Count|

EC2 utility functions and scripts

Rewriting these things every new job is tiresome, so I'm making an open
source version so I can stop having to do that.

Installation
------------

``pip install haze``

License
-------

Everything in this repo is Apache 2.0 licensed.

.. |GitHub stars| image:: https://img.shields.io/github/stars/unixorn/haze.svg
   :target: https://github.com/unixorn/haze/stargazers
.. |Code Climate| image:: https://codeclimate.com/github/unixorn/haze/badges/gpa.svg
   :target: https://codeclimate.com/github/unixorn/haze
.. |Issue Count| image:: https://codeclimate.com/github/unixorn/haze/badges/issue_count.svg
   :target: https://codeclimate.com/github/unixorn/haze
